Timezones | Natural Earth
Description: Includes 24+ timezones with local offsets and map color codes. About Time zones primarily derive from the Central Intelligence Agency map

#

Free vector and raster map data at 1:10m, 1:50m, and 1:110m scales
Search for:

- Home
- Features
- Downloads
- Blog
- Forums
- Corrections
- About

« 1:10m Cultural Vectors « Downloads

## Timezones

Includes 24+ timezones with local offsets and map color codes.

Download time zones (1.88 MB) version 4.0.0

About

Time zones primarily derive from the Central Intelligence Agency map of Time Zones, downloaded from the World Factbook website May 2012. Boundaries were adjusted to fit the Natural Earth line work at a scale of 1:10 million and to follow twelve nautical mile territorial sea boundary lines when running along coasts. Additional research was performed based on recent news to update several areas including the international dateline and time zone adjustments for Samoa and Tokelau and the discarding of daylight savings time in Russia.

Data attributes include time offset from Coordinated Universal Time (UTC, aka “zulu” time) and map color codes for a 6-up and 8-up styling.

(below) image caption

Issues

Does not integrate completely with the ne_10m_admin_0_maritime_indicators and ne_10m_admin_0_pacific_grouping_lines due to countries with split zones and other particularities of mapping time zones.

Resources

- CIA World Factbook for PDF map of global timezones, May 3rd, 2012
- tz_world, an efele.net/tz map

Copyright and Terms of Use

The time zones have been donated to Natural Earth by International Mapping Associates, Inc. (see their release). The Natural Earth time zones are in the public domain and supplementary attribution to International Mapping or the Central Intelligence Agency is optional.

Version History

- 4.0.0
- 2.0.0

The master changelog is available on Github »